/**
 * Copyright (c) 2015 CEA LIST.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     CEA LIST - initial API and implementation
 */
package org.eclipse.papyrus.cpp.codegen.xtend;

import org.eclipse.emf.common.util.EList;
import org.eclipse.papyrus.codegen.base.GenUtils;
import org.eclipse.papyrus.cpp.codegen.utils.CppGenUtils;
import org.eclipse.papyrus.cpp.codegen.xtend.CppClassAttributesDeclaration;
import org.eclipse.papyrus.cpp.codegen.xtend.CppClassFriendDeclaration;
import org.eclipse.papyrus.cpp.codegen.xtend.CppClassInheritedDeclarations;
import org.eclipse.papyrus.cpp.codegen.xtend.CppClassOperationsDeclaration;
import org.eclipse.papyrus.cpp.codegen.xtend.CppClassTypeAndEnum;
import org.eclipse.papyrus.cpp.codegen.xtend.CppClassifierGenerator;
import org.eclipse.papyrus.cpp.codegen.xtend.CppDocumentation;
import org.eclipse.papyrus.cpp.codegen.xtend.CppTemplates;
import org.eclipse.uml2.uml.Classifier;
import org.eclipse.uml2.uml.Element;
import org.eclipse.uml2.uml.NamedElement;
import org.eclipse.uml2.uml.TemplateBinding;
import org.eclipse.uml2.uml.TemplateParameterSubstitution;
import org.eclipse.uml2.uml.VisibilityKind;
import org.eclipse.xtend2.lib.StringConcatenation;

/**
 * @author Shuai Li (CEA) <shuai.li@cea.fr>
 */
@SuppressWarnings("all")
public class CppInnerClassifiers {
  public static Object CppInnerClassDefinition(final Classifier classifier) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _CppElementDoc = CppDocumentation.CppElementDoc(classifier);
    _builder.append(_CppElementDoc, "");
    _builder.newLineIfNotEmpty();
    CharSequence _templateSignature = CppTemplates.templateSignature(classifier);
    _builder.append(_templateSignature, "");
    String _classUnionOrStruct = CppClassifierGenerator.classUnionOrStruct(classifier);
    _builder.append(_classUnionOrStruct, "");
    _builder.append(" ");
    String _name = classifier.getName();
    _builder.append(_name, "");
    CharSequence _CppClassInheritedDeclarations = CppClassInheritedDeclarations.CppClassInheritedDeclarations(classifier);
    _builder.append(_CppClassInheritedDeclarations, "");
    _builder.append(" {");
    _builder.newLineIfNotEmpty();
    CppClassFriendDeclaration.CppClassIncludeFriendDeclaration(classifier);
    CharSequence _CppClassTypeAndEnum = CppClassTypeAndEnum.CppClassTypeAndEnum(classifier);
    _builder.append(_CppClassTypeAndEnum, "");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    VisibilityKind publicVisibility = VisibilityKind.PUBLIC_LITERAL;
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    String _defaultInitializer = CppClassifierGenerator.defaultInitializer(classifier);
    String _section = CppGenUtils.getSection(publicVisibility, _defaultInitializer);
    _builder.append(_section, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _CppClassAttributesDeclaration = CppClassAttributesDeclaration.CppClassAttributesDeclaration(classifier, publicVisibility);
    String _string = _CppClassAttributesDeclaration.toString();
    String _section_1 = CppGenUtils.getSection(publicVisibility, _string);
    _builder.append(_section_1, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _CppClassOperationsDeclaration = CppClassOperationsDeclaration.CppClassOperationsDeclaration(classifier, publicVisibility);
    String _string_1 = _CppClassOperationsDeclaration.toString();
    String _section_2 = CppGenUtils.getSection(publicVisibility, _string_1);
    _builder.append(_section_2, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    VisibilityKind protectedVisibility = VisibilityKind.PROTECTED_LITERAL;
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _CppClassAttributesDeclaration_1 = CppClassAttributesDeclaration.CppClassAttributesDeclaration(classifier, protectedVisibility);
    String _string_2 = _CppClassAttributesDeclaration_1.toString();
    String _section_3 = CppGenUtils.getSection(protectedVisibility, _string_2);
    _builder.append(_section_3, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _CppClassOperationsDeclaration_1 = CppClassOperationsDeclaration.CppClassOperationsDeclaration(classifier, protectedVisibility);
    String _string_3 = _CppClassOperationsDeclaration_1.toString();
    String _section_4 = CppGenUtils.getSection(protectedVisibility, _string_3);
    _builder.append(_section_4, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    VisibilityKind privateVisibility = VisibilityKind.PRIVATE_LITERAL;
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _CppClassAttributesDeclaration_2 = CppClassAttributesDeclaration.CppClassAttributesDeclaration(classifier, privateVisibility);
    String _string_4 = _CppClassAttributesDeclaration_2.toString();
    String _section_5 = CppGenUtils.getSection(privateVisibility, _string_4);
    _builder.append(_section_5, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _CppClassOperationsDeclaration_2 = CppClassOperationsDeclaration.CppClassOperationsDeclaration(classifier, privateVisibility);
    String _string_5 = _CppClassOperationsDeclaration_2.toString();
    String _section_6 = CppGenUtils.getSection(privateVisibility, _string_5);
    _builder.append(_section_6, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("};");
    _builder.newLine();
    return _builder;
  }
  
  public static CharSequence CppInnerBindDefinition(final Classifier classifier) {
    StringConcatenation _builder = new StringConcatenation();
    TemplateBinding tb = GenUtils.getTemplateBinding(classifier);
    _builder.newLineIfNotEmpty();
    EList<Element> _targets = tb.getTargets();
    Element templateElement = _targets.get(0);
    _builder.newLineIfNotEmpty();
    _builder.append("/************************************************************/");
    _builder.newLine();
    _builder.append("typedef ");
    Element _owner = templateElement.getOwner();
    String _name = ((NamedElement) _owner).getName();
    _builder.append(_name, "");
    _builder.append("<");
    {
      EList<TemplateParameterSubstitution> _parameterSubstitutions = tb.getParameterSubstitutions();
      boolean _hasElements = false;
      for(final TemplateParameterSubstitution ps : _parameterSubstitutions) {
        if (!_hasElements) {
          _hasElements = true;
        } else {
          _builder.appendImmediate(", ", "");
        }
        Object _CppTemplateBindingParameter = CppTemplates.CppTemplateBindingParameter(ps);
        _builder.append(_CppTemplateBindingParameter, "");
      }
    }
    _builder.append("> ");
    String _name_1 = classifier.getName();
    _builder.append(_name_1, "");
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
}
