package org.eclipse.papyrus.qompass.modellibs.core.xtend;

import org.eclipse.emf.common.util.EList;
import org.eclipse.papyrus.qompass.designer.core.UMLTool;
import org.eclipse.papyrus.qompass.modellibs.core.xtend.CppUtils;
import org.eclipse.uml2.uml.Operation;
import org.eclipse.uml2.uml.Parameter;
import org.eclipse.uml2.uml.Type;
import org.eclipse.xtend2.lib.StringConcatenation;

@SuppressWarnings("all")
public class Marshalling {
  public static CharSequence marshall(final Operation operation) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("// now marshall in and inout parameters via ASN.1");
    _builder.newLine();
    {
      EList<Parameter> _parametersInInout = UMLTool.parametersInInout(operation);
      for(final Parameter parameter : _parametersInInout) {
        CharSequence _marshall = Marshalling.marshall(parameter);
        _builder.append(_marshall, "");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  public static CharSequence marshallOutInout(final Operation operation) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("// now marshall out and inout parameters via ASN.1");
    _builder.newLine();
    {
      EList<Parameter> _parametersOutInout = UMLTool.parametersOutInout(operation);
      for(final Parameter parameter : _parametersOutInout) {
        CharSequence _marshall = Marshalling.marshall(parameter);
        _builder.append(_marshall, "");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  public static CharSequence marshall(final Parameter parameter) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("{");
    _builder.newLine();
    _builder.append("\t");
    Type _type = parameter.getType();
    CharSequence _cppType = CppUtils.cppType(_type);
    _builder.append(_cppType, "\t");
    _builder.append(" varName_ASN = ");
    String _name = parameter.getName();
    _builder.append(_name, "\t");
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("BEncAsnContent (&pBuffer, &varName_ASN);");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public static CharSequence unmarshall(final Operation operation) {
    StringConcatenation _builder = new StringConcatenation();
    {
      EList<Parameter> _parametersInInout = UMLTool.parametersInInout(operation);
      EList<Parameter> _reverse = UMLTool.<Parameter>reverse(_parametersInInout);
      for(final Parameter parameter : _reverse) {
        CharSequence _unmarshall = Marshalling.unmarshall(parameter);
        _builder.append(_unmarshall, "");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  public static CharSequence unmarshallOutInout(final Operation operation) {
    StringConcatenation _builder = new StringConcatenation();
    {
      EList<Parameter> _parametersOutInout = UMLTool.parametersOutInout(operation);
      EList<Parameter> _reverse = UMLTool.<Parameter>reverse(_parametersOutInout);
      for(final Parameter parameter : _reverse) {
        CharSequence _unmarshall = Marshalling.unmarshall(parameter);
        _builder.append(_unmarshall, "");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  public static CharSequence unmarshall(final Parameter parameter) {
    StringConcatenation _builder = new StringConcatenation();
    Type _type = parameter.getType();
    CharSequence _cppType = CppUtils.cppType(_type);
    _builder.append(_cppType, "");
    _builder.append(" ");
    String _name = parameter.getName();
    _builder.append(_name, "");
    _builder.newLineIfNotEmpty();
    _builder.append("{");
    _builder.newLine();
    _builder.append("\t");
    Type _type_1 = parameter.getType();
    CharSequence _cppType_1 = CppUtils.cppType(_type_1);
    _builder.append(_cppType_1, "\t");
    _builder.append(" varName_ASN;");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("BDecAsnContent (&pBuffer, &varName_ASN);");
    _builder.newLine();
    _builder.append("\t");
    String _name_1 = parameter.getName();
    _builder.append(_name_1, "\t");
    _builder.append(" = varName_ASN;");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
}
