/**
 * Copyright (c) 2014 Zeligsoft, CEA and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.eclipse.papyrus.qompass.modellibs.core.xtend;

import com.google.common.base.Objects;
import java.util.ArrayList;
import java.util.List;
import org.eclipse.uml2.uml.Behavior;
import org.eclipse.uml2.uml.BehavioralFeature;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Pure;

/**
 * An action in the sense of the invocation of a behavior.
 * This means that the actual behavior is not described here. The action
 * is referencing the behavior and providing information how to invoke the
 * behavior.
 * The action has no prefix: the name of the referenced behavior needs to be prefixed, if necessary
 * 
 * @author Ansgar (based on code from eposse)
 */
@SuppressWarnings("all")
public class UMLAction {
  /**
   * Source UMLRT model element.
   */
  @Accessors
  private Behavior origin;
  
  public List<String> callParams;
  
  public UMLAction(final Behavior origin) {
    this.origin = origin;
  }
  
  /**
   * Add a parameter
   */
  public boolean addParam(final String parameter) {
    boolean _xblockexpression = false;
    {
      boolean _equals = Objects.equal(this.callParams, null);
      if (_equals) {
        ArrayList<String> _arrayList = new ArrayList<String>();
        this.callParams = _arrayList;
      }
      _xblockexpression = this.callParams.add(parameter);
    }
    return _xblockexpression;
  }
  
  public BehavioralFeature getSpecification() {
    return this.origin.getSpecification();
  }
  
  public String getFuncName() {
    return this.origin.getName();
  }
  
  public String toString() {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("Action(");
    String _name = this.origin.getName();
    _builder.append(_name, "");
    _builder.append(")");
    return _builder.toString();
  }
  
  @Pure
  public Behavior getOrigin() {
    return this.origin;
  }
  
  public void setOrigin(final Behavior origin) {
    this.origin = origin;
  }
}
